# Generated by Django 2.1.2 on 2019-09-03 01:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('autopost', '0008_auto_20190829_0935'),
    ]

    operations = [
        migrations.AlterField(
            model_name='category',
            name='slug',
            field=models.CharField(blank=True, max_length=128, verbose_name='标识'),
        ),
        migrations.AlterField(
            model_name='category',
            name='status',
            field=models.IntegerField(choices=[(1, '显示'), (0, '隐藏'), (2, '主菜单')], default=1, verbose_name='状态'),
        ),
    ]
