# Generated by Django 2.1.2 on 2019-09-06 15:18

from django.db import migrations, models
import django.db.models.deletion
import mptt.fields


class Migration(migrations.Migration):

    dependencies = [
        ('autopost', '0009_auto_20190903_0948'),
    ]

    operations = [
        migrations.AlterField(
            model_name='article',
            name='category',
            field=mptt.fields.TreeForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='category', to='autopost.Category', verbose_name='所属分类'),
        ),
        migrations.AlterField(
            model_name='article',
            name='site',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.DO_NOTHING, to='sites.Site', verbose_name='所属站点'),
        ),
        migrations.AlterField(
            model_name='category',
            name='parent',
            field=mptt.fields.TreeForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='children', to='autopost.Category', verbose_name='上级菜单'),
        ),
        migrations.AlterField(
            model_name='category',
            name='status',
            field=models.IntegerField(choices=[(1, '显示'), (2, '主菜单'), (0, '隐藏')], default=1, verbose_name='状态'),
        ),
    ]
