# Generated by Django 2.1.2 on 2019-08-25 09:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('system', '0007_auto_20190731_1528'),
    ]

    operations = [
        migrations.AddField(
            model_name='recommended',
            name='slug',
            field=models.SlugField(blank=True, verbose_name='标签'),
        ),
        migrations.AlterField(
            model_name='menu',
            name='type',
            field=models.IntegerField(choices=[(3, '论坛'), (2, '文章'), (1, '店铺')], default=1, verbose_name='类别'),
        ),
    ]
