# Generated by Django 2.1.2 on 2019-05-07 15:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('system', '0005_auto_20181108_0915'),
    ]

    operations = [
        migrations.AlterField(
            model_name='menu',
            name='url',
            field=models.CharField(blank=True, max_length=255, verbose_name='地址'),
        ),
    ]
