# Generated by Django 2.1.2 on 2019-08-29 01:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('autopost', '0007_auto_20190507_2329'),
    ]

    operations = [
        migrations.AddField(
            model_name='autotask',
            name='thumbnail_selector',
            field=models.CharField(blank=True, max_length=128, verbose_name='缩略图规则'),
        ),
        migrations.AlterField(
            model_name='article',
            name='status',
            field=models.BooleanField(choices=[(True, '是'), (False, '否')], default=True, verbose_name='是否显示'),
        ),
        migrations.AlterField(
            model_name='category',
            name='status',
            field=models.IntegerField(choices=[(1, '显示'), (2, '主菜单'), (0, '隐藏')], default=1, verbose_name='状态'),
        ),
        migrations.AlterField(
            model_name='remoteimages',
            name='origin_src',
            field=models.CharField(db_index=True, max_length=255, verbose_name='原始地址'),
        ),
        migrations.AlterField(
            model_name='remoteimages',
            name='remote_src',
            field=models.CharField(blank=True, db_index=True, max_length=255, null=True, verbose_name='远程地址'),
        ),
    ]
