# Generated by Django 2.1.2 on 2019-07-31 07:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('system', '0006_auto_20190507_2329'),
    ]

    operations = [
        migrations.CreateModel(
            name='Recommended',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(db_index=True, max_length=128, verbose_name='标签')),
                ('status', models.IntegerField(choices=[(2, '隐藏'), (1, '显示')], default=1, verbose_name='状态')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='创建时间')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='更新时间')),
            ],
            options={
                'verbose_name': '推荐标签',
                'verbose_name_plural': '推荐标签管理',
                'db_table': 'sys_recommend',
            },
        ),
        migrations.AlterField(
            model_name='menu',
            name='status',
            field=models.IntegerField(choices=[(2, '隐藏'), (1, '显示')], default=1, verbose_name='状态'),
        ),
        migrations.AlterField(
            model_name='menu',
            name='type',
            field=models.IntegerField(choices=[(1, '店铺'), (3, '论坛'), (2, '文章')], default=1, verbose_name='类别'),
        ),
    ]
