# Generated by Django 2.1.2 on 2019-09-06 15:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('system', '0009_auto_20190831_0726'),
    ]

    operations = [
        migrations.AlterField(
            model_name='menu',
            name='status',
            field=models.IntegerField(choices=[(1, '显示'), (2, '隐藏')], default=1, verbose_name='状态'),
        ),
        migrations.AlterField(
            model_name='menu',
            name='type',
            field=models.IntegerField(choices=[(2, '文章'), (1, '店铺'), (3, '论坛')], default=1, verbose_name='类别'),
        ),
        migrations.AlterField(
            model_name='recommended',
            name='status',
            field=models.IntegerField(choices=[(1, '显示'), (2, '隐藏')], default=1, verbose_name='状态'),
        ),
        migrations.AlterUniqueTogether(
            name='menu',
            unique_together={('parent', 'slug')},
        ),
    ]
